import { LayerObject, Line, LineSegment, Vec2 } from '../interfaces';
import { CanvasToolBase } from './tool-base';

export type CutToolType = 'cut' | 'remove-segment';
export class CutTool extends CanvasToolBase<CutToolType> {
  public name = 'cut';
  public subTool: CutToolType | undefined = 'cut';

  mouseMoved(mouse: Vec2, offset: Vec2, mouseAbsolute: Vec2) {
    super.mouseMoved(mouse, offset, mouseAbsolute);
    this.renderer.draw();
  }
  mouseDown(targetObject?: LayerObject | undefined): void {
    if (
      !targetObject ||
      targetObject.type === 'curve' ||
      targetObject.type === 'object'
    )
      return;
    const line = targetObject as Line;
    const segment = this.manager.getMousedLineSegment(line);
    if (!segment) return;
    const segmentIndex = line.segments.indexOf(segment);

    if (this.subTool === 'remove-segment') {
      const nextSegment = line.segments[segmentIndex + 1];
      if (!nextSegment) return;
      if (segment.start) {
        nextSegment.start = segment.start;
        line.segments.splice(segmentIndex, 1);
      } else {
        nextSegment.start = segment.end;
        line.segments.splice(segmentIndex, 1);
      }
    } else {
      const currentEnd: Vec2 = [...segment.end];
      segment.end = [...this.mousePosition];
      line.segments.splice(segmentIndex + 1, 0, { end: currentEnd });
    }
    this.renderer.draw();
  }

  drawLineControls(line: LineSegment) {
    const [endx, endy] = line.end;
    this.ctx.fillStyle = '#00ddffaa';

    this.ctx.beginPath();
    this.ctx.arc(endx, endy, this.manager.selectError / 2, 0, 2 * Math.PI);
    this.ctx.fill();

    if (line.start) {
      const [startx, starty] = line.start;
      this.ctx.beginPath();
      this.ctx.arc(
        startx,
        starty,
        this.manager.selectError / 2,
        0,
        2 * Math.PI
      );
      this.ctx.fill();
    }
  }

  drawControls(): void {
    for (const object of this.manager.selectedObjects) {
      const line = object as Line;
      if (line.segments && line.render) {
        for (const segment of line.segments) {
          this.drawLineControls(segment);
        }
      }
    }

    const [mx, my] = this.mousePosition;
    this.ctx.fillStyle = '#00ddffaa';
    this.ctx.beginPath();
    this.ctx.arc(mx, my, this.manager.selectError / 2, 0, 2 * Math.PI);
    this.ctx.fill();
  }
}
